#
# -*- coding: utf-8 -*-
# Copyright 2019 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
"""
The facts class for apl
this file validates each subset of facts and selectively
calls the appropriate facts gathering function
"""

from __future__ import absolute_import, division, print_function

__metaclass__ = type


from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.facts.facts import (
    FactsBase,
)
from ansible_collections.apresia.apl.plugins.module_utils.network.apl.facts.interfaces.interfaces import (
    InterfacesFacts,
)
from ansible_collections.apresia.apl.plugins.module_utils.network.apl.facts.l2_interfaces.l2_interfaces import (
    L2_InterfacesFacts,
)
from ansible_collections.apresia.apl.plugins.module_utils.network.apl.facts.vlans.vlans import (
    VlansFacts,
)
from ansible_collections.apresia.apl.plugins.module_utils.network.apl.facts.static_routes.static_routes import (
    Static_RoutesFacts,
)
from ansible_collections.apresia.apl.plugins.module_utils.network.apl.facts.logging_global.logging_global import (
    Logging_globalFacts,
)
from ansible_collections.apresia.apl.plugins.module_utils.network.apl.facts.snmp_server.snmp_server import (
    Snmp_serverFacts,
)
from ansible_collections.apresia.apl.plugins.module_utils.network.apl.facts.hostname.hostname import (
     HostnameFacts,
)
from ansible_collections.apresia.apl.plugins.module_utils.network.apl.facts.legacy.base import (
    Default,
    Hardware,
    Interfaces,
    Config,
)


FACT_LEGACY_SUBSETS = dict(
    default=Default, hardware=Hardware, interfaces=Interfaces, config=Config
)

FACT_RESOURCE_SUBSETS = dict(
    interfaces=InterfacesFacts,
    l2_interfaces=L2_InterfacesFacts,
    vlans=VlansFacts,
    static_routes=Static_RoutesFacts,
    logging_global=Logging_globalFacts,
    snmp_server=Snmp_serverFacts,
    hostname=HostnameFacts,
)


class Facts(FactsBase):
    """The fact class for apl"""

    VALID_LEGACY_GATHER_SUBSETS = frozenset(FACT_LEGACY_SUBSETS.keys())
    VALID_RESOURCE_SUBSETS = frozenset(FACT_RESOURCE_SUBSETS.keys())

    def __init__(self, module):
        super(Facts, self).__init__(module)

    def get_facts(
        self, legacy_facts_type=None, resource_facts_type=None, data=None
    ):
        """Collect the facts for apl
        :param legacy_facts_type: List of legacy facts types
        :param resource_facts_type: List of resource fact types
        :param data: previously collected conf
        :rtype: dict
        :return: the facts gathered
        """
        if self.VALID_RESOURCE_SUBSETS:
            self.get_network_resources_facts(
                FACT_RESOURCE_SUBSETS, resource_facts_type, data
            )

        if self.VALID_LEGACY_GATHER_SUBSETS:
            self.get_network_legacy_facts(
                FACT_LEGACY_SUBSETS, legacy_facts_type
            )

        return self.ansible_facts, self._warnings
