#
# -*- coding: utf-8 -*-
# Copyright 2019 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
"""
The apl_static_routes fact class
It is in this file the configuration is collected from the device
for a given resource, parsed, and the facts tree is populated
based on the configuration.
"""

from __future__ import absolute_import, division, print_function

__metaclass__ = type

from ansible_collections.ansible.netcommon.plugins.module_utils.network.common import (
    utils,
)
from ansible_collections.apresia.apl.plugins.module_utils.network.apl.rm_templates.static_routes import (
    Static_routesTemplate,
)


class Static_RoutesFacts(object):
    """The apl_static_routes fact class"""

    def __init__(self, module, subspec="config", options="options"):
        self._module = module

    def get_static_routes_data(self, connection):
        route_result = connection.get("show running-config all function ROUTE")
        route6_result = connection.get("show running-config all function ROUTE6")

        return route_result, route6_result

    def populate_facts(self, connection, ansible_facts, data=None):
        """Populate the facts for static_routes
        :param connection: the device connection
        :param ansible_facts: Facts dictionary
        :param data: previously collected conf
        :rtype: dictionary
        :returns: facts
        """

        objs = []

        if not data:
            data = self.get_static_routes_data(connection)

        
        for devide_ip_type in data:
            # operate on a collection of resource x
            slice_data = devide_ip_type.split("\n")

            # parse native config using the Static_routes template
            if slice_data:
                static_routes_parser = Static_routesTemplate(
                    lines=slice_data, module=self._module
                )
                obj = static_routes_parser.parse()
                if obj:
                    objs.append(obj)

        facts = {}

        if objs:
            ansible_facts["ansible_network_resources"].pop("static_routes", None)

            params = utils.remove_empties(
                {"config": objs}
            )

            facts["static_routes"] = params.get("config", {})
            ansible_facts["ansible_network_resources"].update(facts)
        
        return ansible_facts